@@ -44,8 +44,10 @@ class payUnit:
         return_url = str(self.config_data["return_url"])
         notify_url = str(self.config_data["notify_url"])
         
-        test_url = 'http://192.168.100.70:5000/api/gateway/initialize'
+        test_url = 'https://app-payunit.sevengps.net/sandbox/gateway/initialize'
+        # test_url = 'http://192.168.100.70:5000/sandbox/gateway/initialize'
         # test_url = "http://localhost:5000/notify"
+        test_url_2 = 'https://app-payunit.sevengps.net/api/gateway/initialize'
 
         headers = {
             "x-api-key": str(api_key),
@@ -61,10 +63,13 @@ class payUnit:
             "total_amount": str(amount),
             "return_url": str(self.config_data['return_url']), 
         }
-        # response = requests.post(test_url,data = json.dumps(test_body),headers = headers)
-        # print(response.content)
-        try:   
-            response = requests.post(test_url,data = json.dumps(test_body),headers = headers)
+
+
+        try: 
+            if(str(environment.lower())=="test"):
+                response = requests.post(test_url,data = json.dumps(test_body),headers = headers)
+            else:
+                response = requests.post(test_url_2,data = json.dumps(test_body),headers = headers) 
             response = response.json()
             if(response['body']['status'] == 200):
                 webbrowser.open(response['body']['transaction_url'])
